%define major 6
%define libname %mklibname %{name} %{major}
%define devname %mklibname -d %{name}

Name:       shibboleth-sp
Version:    2.5.3
Release:    %mkrel 1
Summary:    Open source system for attribute-based Web SSO
Group:      System/Servers
License:    Apache 2.0
URL:        http://shibboleth.net/
Source0:    http://shibboleth.net/downloads/service-provider/%{version}/%{name}-%{version}.tar.gz
Source1:    shibd.service
Source2:    shibd.tmpfiles
BuildRequires:  xmltooling-schemas
BuildRequires:  opensaml-schemas
BuildRequires:  xerces-c-devel >= 2.8.0
BuildRequires:  xml-security-c-devel >= 1.4.0
BuildRequires:  xmltooling-devel >= 1.5.0
BuildRequires:  opensaml-devel >= 2.5.0
BuildRequires:  log4shib-devel >= 1.0.4
BuildRequires:  boost-devel >= 1.32.0
BuildRequires:  doxygen
BuildRequires:  unixODBC-devel
BuildRequires:  libfcgi-devel
BuildRequires:  libmemcached-devel
BuildRequires:  apache-devel
Requires(post): systemd >= %{systemd_required_version}

%description
Shibboleth is a Web Single Sign-On implementations based on OpenSAML
that supports multiple protocols, federated identity, and the extensible
exchange of rich attributes subject to privacy controls.

This package contains the Shibboleth Service Provider daemon and default
plugins.

%package -n apache-mod_shib
Summary:    Shibboleth library
Group:      System/Servers

%description -n apache-mod_shib
Shibboleth is a Web Single Sign-On implementations based on OpenSAML
that supports multiple protocols, federated identity, and the extensible
exchange of rich attributes subject to privacy controls.

This package contains just the apache module.

%package -n %{libname}
Summary:    Shibboleth library
Group:      System/Libraries

%description -n %{libname}
Shibboleth is a Web Single Sign-On implementations based on OpenSAML
that supports multiple protocols, federated identity, and the extensible
exchange of rich attributes subject to privacy controls.

This package contains just the shared library.

%package -n %{devname}
Summary:    Shibboleth Development Headers
Group:      Development/C++
Requires:   %{libname} = %{version}-%{release}

%description -n %{devname}
Shibboleth is a Web Single Sign-On implementations based on OpenSAML
that supports multiple protocols, federated identity, and the extensible
exchange of rich attributes subject to privacy controls.

This package includes files needed for development with Shibboleth.

%prep
%setup -q

%build
%configure2_5x PTHREAD_CFLAGS=-pthread PTHREAD_LIBS=-lpthread
%make

%install
rm -rf %{buildroot}
%makeinstall_std pkgdocdir=%{_docdir}/%{name} NOKEYGEN=1

# clean up configuration
rm -f %{buildroot}%{_sysconfdir}/shibboleth/*.dist
rm -f %{buildroot}%{_sysconfdir}/shibboleth/shibd-{debian,redhat,suse}
rm -f %{buildroot}%{_sysconfdir}/shibboleth/shibd-osx.plist
rm -f %{buildroot}%{_sysconfdir}/shibboleth/apache*.config

# systemd
install -D -m 644 %{SOURCE1} %{buildroot}%{_unitdir}/shibd.service
install -D -m 644 %{SOURCE2} %{buildroot}%{_tmpfilesdir}/shibd.conf

# apache
install -d -m 755 %{buildroot}%{_libdir}/httpd/modules
mv %{buildroot}%{_libdir}/shibboleth/mod_shib_24.so \
    %{buildroot}%{_libdir}/httpd/modules

install -d -m 755 %{buildroot}%{_sysconfdir}/httpd/conf/modules.d
cat > %{buildroot}%{_sysconfdir}/httpd/conf/modules.d/10_mod_shib.conf <<EOF
LoadModule mod_shib modules/mod_shib_24.so
EOF

install -d -m 755 %{buildroot}%{_sysconfdir}/httpd/conf/conf.d
cat > %{buildroot}%{_sysconfdir}/httpd/conf/conf.d/mod_shib.conf <<EOF
Alias /shibboleth-sp/main.css /usr/share/shibboleth/main.css
<Location /shibboleth-sp>
    Allow from all
</Location>
EOF

%check
%{__make} check

%pre
%_pre_useradd shibd /run/shibboleth /bin/false

%post
%_create_ssl_certificate shibd -g shibd
%_tmpfilescreate shibd
%_post_service shibd

%preun
%_preun_service shibd

%postun
%_postun_userdel shibd

%files
%{_sbindir}/shibd
%{_bindir}/mdquery
%{_bindir}/resolvertest
%{_libdir}/shibboleth
%attr(0750,shibd,shibd) %dir %{_localstatedir}/log/shibboleth
%attr(0755,shibd,shibd) %dir %{_localstatedir}/cache/shibboleth
%{_datadir}/xml/shibboleth
%{_datadir}/shibboleth
%{_unitdir}/shibd.service
%{_tmpfilesdir}/shibd.conf
%config(noreplace) %{_sysconfdir}/shibboleth/*.xml
%config(noreplace) %{_sysconfdir}/shibboleth/*.html
%config(noreplace) %{_sysconfdir}/shibboleth/*.logger
%{_sysconfdir}/shibboleth/keygen.sh
%{_sysconfdir}/shibboleth/metagen.sh
%{_sysconfdir}/shibboleth/*.xsl
%{_docdir}/%{name}
%exclude %{_docdir}/%{name}/api

%files -n apache-mod_shib
%{_libdir}/httpd/modules/mod_shib_24.so
%config(noreplace) %{_sysconfdir}/httpd/conf/modules.d/10_mod_shib.conf
%config(noreplace) %{_sysconfdir}/httpd/conf/conf.d/mod_shib.conf

%files -n %{libname}
%{_libdir}/libshibsp.so.%{major}*
%{_libdir}/libshibsp-lite.so.%{major}*

%files -n %{devname}
%{_docdir}/%{name}/api
%{_includedir}/*
%{_libdir}/libshibsp.so
%{_libdir}/libshibsp-lite.so


%changelog
* Wed Dec 04 2013 guillomovitch <guillomovitch> 2.5.3-1.mga4
+ Revision: 555094
- new version

* Sat Oct 19 2013 umeabot <umeabot> 2.5.1-6.mga4
+ Revision: 529598
- Mageia 4 Mass Rebuild

* Wed Jul 10 2013 fwang <fwang> 2.5.1-5.mga4
+ Revision: 452530
- rebuild for new boost

* Sun Mar 24 2013 colin <colin> 2.5.1-4.mga3
+ Revision: 404859
- Add systemd requires and general post/pre fixes (mga#9302)

* Mon Jan 14 2013 umeabot <umeabot> 2.5.1-3.mga3
+ Revision: 381965
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sat Jan 12 2013 colin <colin> 2.5.1-2.mga3
+ Revision: 358736
- Use tmpfiles macros
- Do not ship /var/run dir (rely only on tmpfiles)

* Thu Jan 03 2013 guillomovitch <guillomovitch> 2.5.1-1.mga3
+ Revision: 338162
- imported package shibboleth-sp

